diff mbox

[v5,1/2] of: Rename "poweroff-source" property to "system-power-controller"

Message ID 1416918506-9366-2-git-send-email-romain.perier@gmail.com
State Accepted, archived
Commit 8f73110f6bac043026bc923b0a66abe24dd48058
Headers show

Commit Message

Romain Perier Nov. 25, 2014, 12:28 p.m. UTC
It reverts commit a4b4e0461ec5 ("of: Add standard property for poweroff capability").
As discussed on the mailing list, it makes more sense to rename back to the
old established property name, without the vendor prefix. Problem being that
the word "source" usually tends to be used for inputs and that is out of control
of the OS. The poweroff capability is an output which simply turns the
system-power off. Also, this property might be used by drivers which power-off
the system and power back on subsequent RTC alarms. This seems to suggest to
remove "poweroff" from the property name and to choose "system-power-controller"
as the more generic name. This patchs adds the required renaming changes and
defines an helper function which checks if this property is set.

Signed-off-by: Romain Perier <romain.perier@gmail.com>
---
 .../bindings/power/{poweroff.txt => power-controller.txt}           | 0
 Documentation/devicetree/bindings/regulator/act8865-regulator.txt   | 4 ++--
 drivers/regulator/act8865-regulator.c                               | 2 +-
 include/linux/of.h                                                  | 6 +++---
 4 files changed, 6 insertions(+), 6 deletions(-)
 rename Documentation/devicetree/bindings/power/{poweroff.txt => power-controller.txt} (100%)

Comments

Johan Hovold Nov. 25, 2014, 2:07 p.m. UTC | #1
On Tue, Nov 25, 2014 at 12:28:25PM +0000, Romain Perier wrote:
> It reverts commit a4b4e0461ec5 ("of: Add standard property for poweroff capability").
> As discussed on the mailing list, it makes more sense to rename back to the
> old established property name, without the vendor prefix. Problem being that
> the word "source" usually tends to be used for inputs and that is out of control
> of the OS. The poweroff capability is an output which simply turns the
> system-power off. Also, this property might be used by drivers which power-off
> the system and power back on subsequent RTC alarms. This seems to suggest to
> remove "poweroff" from the property name and to choose "system-power-controller"
> as the more generic name. This patchs adds the required renaming changes and
> defines an helper function which checks if this property is set.
> 
> Signed-off-by: Romain Perier <romain.perier@gmail.com>

Acked-by: Johan Hovold <johan@kernel.org>

Mark, this is for the regulator tree.

Thanks,
Johan
--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Grant Likely Nov. 25, 2014, 2:40 p.m. UTC | #2
On Tue, 25 Nov 2014 12:28:25 +0000
, Romain Perier <romain.perier@gmail.com>
 wrote:
> It reverts commit a4b4e0461ec5 ("of: Add standard property for poweroff capability").
> As discussed on the mailing list, it makes more sense to rename back to the
> old established property name, without the vendor prefix. Problem being that
> the word "source" usually tends to be used for inputs and that is out of control
> of the OS. The poweroff capability is an output which simply turns the
> system-power off. Also, this property might be used by drivers which power-off
> the system and power back on subsequent RTC alarms. This seems to suggest to
> remove "poweroff" from the property name and to choose "system-power-controller"
> as the more generic name. This patchs adds the required renaming changes and
> defines an helper function which checks if this property is set.
> 
> Signed-off-by: Romain Perier <romain.perier@gmail.com>

For both patches:
Acked-by: Grant Likely <grant.likely@linaro.org>

Let me know if I need to take this series through my tree. Also, does it
need to go into v3.18 and be backported to stable? Or just v3.19.

g.

> ---
>  .../bindings/power/{poweroff.txt => power-controller.txt}           | 0
>  Documentation/devicetree/bindings/regulator/act8865-regulator.txt   | 4 ++--
>  drivers/regulator/act8865-regulator.c                               | 2 +-
>  include/linux/of.h                                                  | 6 +++---
>  4 files changed, 6 insertions(+), 6 deletions(-)
>  rename Documentation/devicetree/bindings/power/{poweroff.txt => power-controller.txt} (100%)
> 
> diff --git a/Documentation/devicetree/bindings/power/poweroff.txt b/Documentation/devicetree/bindings/power/power-controller.txt
> similarity index 100%
> rename from Documentation/devicetree/bindings/power/poweroff.txt
> rename to Documentation/devicetree/bindings/power/power-controller.txt
> diff --git a/Documentation/devicetree/bindings/regulator/act8865-regulator.txt b/Documentation/devicetree/bindings/regulator/act8865-regulator.txt
> index 01a5b07..dad6358 100644
> --- a/Documentation/devicetree/bindings/regulator/act8865-regulator.txt
> +++ b/Documentation/devicetree/bindings/regulator/act8865-regulator.txt
> @@ -6,8 +6,8 @@ Required properties:
>  - reg: I2C slave address
>  
>  Optional properties:
> -- poweroff-source: Telling whether or not this pmic is controlling
> -  the system power. See Documentation/devicetree/bindings/power/poweroff.txt .
> +- system-power-controller: Telling whether or not this pmic is controlling
> +  the system power. See Documentation/devicetree/bindings/power/power-controller.txt .
>  
>  Any standard regulator properties can be used to configure the single regulator.
>  
> diff --git a/drivers/regulator/act8865-regulator.c b/drivers/regulator/act8865-regulator.c
> index 76301ed..9eec453 100644
> --- a/drivers/regulator/act8865-regulator.c
> +++ b/drivers/regulator/act8865-regulator.c
> @@ -365,7 +365,7 @@ static int act8865_pmic_probe(struct i2c_client *client,
>  		return ret;
>  	}
>  
> -	if (of_system_has_poweroff_source(dev->of_node)) {
> +	if (of_device_is_system_power_controller(dev->of_node)) {
>  		if (!pm_power_off) {
>  			act8865_i2c_client = client;
>  			act8865->off_reg = off_reg;
> diff --git a/include/linux/of.h b/include/linux/of.h
> index b81dbcf..0abdd70 100644
> --- a/include/linux/of.h
> +++ b/include/linux/of.h
> @@ -964,14 +964,14 @@ static inline int of_changeset_update_property(struct of_changeset *ocs,
>  extern int of_resolve_phandles(struct device_node *tree);
>  
>  /**
> - * of_system_has_poweroff_source - Tells if poweroff-source is found for device_node
> + * of_device_is_system_power_controller - Tells if system-power-controller is found for device_node
>   * @np: Pointer to the given device_node
>   *
>   * return true if present false otherwise
>   */
> -static inline bool of_system_has_poweroff_source(const struct device_node *np)
> +static inline bool of_device_is_system_power_controller(const struct device_node *np)
>  {
> -	return of_property_read_bool(np, "poweroff-source");
> +	return of_property_read_bool(np, "system-power-controller");
>  }
>  
>  #endif /* _LINUX_OF_H */
> -- 
> 1.9.1
> 

--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Heiko Stübner Nov. 25, 2014, 2:52 p.m. UTC | #3
Am Dienstag, 25. November 2014, 14:40:07 schrieb Grant Likely:
> On Tue, 25 Nov 2014 12:28:25 +0000
> , Romain Perier <romain.perier@gmail.com>
> 
>  wrote:
> > It reverts commit a4b4e0461ec5 ("of: Add standard property for poweroff
> > capability"). As discussed on the mailing list, it makes more sense to
> > rename back to the old established property name, without the vendor
> > prefix. Problem being that the word "source" usually tends to be used for
> > inputs and that is out of control of the OS. The poweroff capability is
> > an output which simply turns the system-power off. Also, this property
> > might be used by drivers which power-off the system and power back on
> > subsequent RTC alarms. This seems to suggest to remove "poweroff" from
> > the property name and to choose "system-power-controller" as the more
> > generic name. This patchs adds the required renaming changes and defines
> > an helper function which checks if this property is set.
> > 
> > Signed-off-by: Romain Perier <romain.perier@gmail.com>
> 
> For both patches:
> Acked-by: Grant Likely <grant.likely@linaro.org>
> 
> Let me know if I need to take this series through my tree. Also, does it
> need to go into v3.18 and be backported to stable? Or just v3.19.

The original change [that is fixed now] is only scheduled for 3.19 and in
Mark Brown's tree [0]. So there shouldn't be anything to do for you now.


Heiko



[0] https://git.kernel.org/cgit/linux/kernel/git/broonie/regulator.git/log/?h=topic/power-off
--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Johan Hovold Nov. 25, 2014, 2:54 p.m. UTC | #4
On Tue, Nov 25, 2014 at 02:40:07PM +0000, Grant Likely wrote:
> On Tue, 25 Nov 2014 12:28:25 +0000
> , Romain Perier <romain.perier@gmail.com>
>  wrote:
> > It reverts commit a4b4e0461ec5 ("of: Add standard property for poweroff capability").
> > As discussed on the mailing list, it makes more sense to rename back to the
> > old established property name, without the vendor prefix. Problem being that
> > the word "source" usually tends to be used for inputs and that is out of control
> > of the OS. The poweroff capability is an output which simply turns the
> > system-power off. Also, this property might be used by drivers which power-off
> > the system and power back on subsequent RTC alarms. This seems to suggest to
> > remove "poweroff" from the property name and to choose "system-power-controller"
> > as the more generic name. This patchs adds the required renaming changes and
> > defines an helper function which checks if this property is set.
> > 
> > Signed-off-by: Romain Perier <romain.perier@gmail.com>
> 
> For both patches:
> Acked-by: Grant Likely <grant.likely@linaro.org>
> 
> Let me know if I need to take this series through my tree. Also, does it
> need to go into v3.18 and be backported to stable? Or just v3.19.

It's only needed in the regulator tree for 3.19, and does not need to be
backported.

We could convert the drivers (and dts) that currently use
"<vendor>,system-power-controller" to use the new helper (while
maintaining backward compatibility) after 3.19-rc1 is out.

Johan
--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Romain Perier Nov. 25, 2014, 3:57 p.m. UTC | #5
Thanks for your feedbacks.  I think that Mark will probably wait until
there are more reviews on this serie. (this is exactly what he asked
for the previous one)

2014-11-25 15:54 GMT+01:00 Johan Hovold <johan@kernel.org>:
> On Tue, Nov 25, 2014 at 02:40:07PM +0000, Grant Likely wrote:
>> On Tue, 25 Nov 2014 12:28:25 +0000
>> , Romain Perier <romain.perier@gmail.com>
>>  wrote:
>> > It reverts commit a4b4e0461ec5 ("of: Add standard property for poweroff capability").
>> > As discussed on the mailing list, it makes more sense to rename back to the
>> > old established property name, without the vendor prefix. Problem being that
>> > the word "source" usually tends to be used for inputs and that is out of control
>> > of the OS. The poweroff capability is an output which simply turns the
>> > system-power off. Also, this property might be used by drivers which power-off
>> > the system and power back on subsequent RTC alarms. This seems to suggest to
>> > remove "poweroff" from the property name and to choose "system-power-controller"
>> > as the more generic name. This patchs adds the required renaming changes and
>> > defines an helper function which checks if this property is set.
>> >
>> > Signed-off-by: Romain Perier <romain.perier@gmail.com>
>>
>> For both patches:
>> Acked-by: Grant Likely <grant.likely@linaro.org>
>>
>> Let me know if I need to take this series through my tree. Also, does it
>> need to go into v3.18 and be backported to stable? Or just v3.19.
>
> It's only needed in the regulator tree for 3.19, and does not need to be
> backported.
>
> We could convert the drivers (and dts) that currently use
> "<vendor>,system-power-controller" to use the new helper (while
> maintaining backward compatibility) after 3.19-rc1 is out.
>
> Johan
--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Mark Brown Nov. 25, 2014, 5:12 p.m. UTC | #6
On Tue, Nov 25, 2014 at 04:57:56PM +0100, Romain Perier wrote:

> Thanks for your feedbacks.  I think that Mark will probably wait until
> there are more reviews on this serie. (this is exactly what he asked
> for the previous one)

Yeah, given the amount of often late arriving disagreement I'd rather
let things cook for a while unless there are a lot of people being vocal
about this being what we want to go with.
Romain Perier Nov. 26, 2014, 10:08 a.m. UTC | #7
2014-11-25 18:12 GMT+01:00 Mark Brown <broonie@kernel.org>:
> Yeah, given the amount of often late arriving disagreement I'd rather
> let things cook for a while unless there are a lot of people being vocal
> about this being what we want to go with.

In other words, I need more reviews and more positives feedbacks about
this serie (as far as people who were against the previous ones).
For example, Feedbacks from Felipe Balbi and Lucas Stach would be welcome.

Thanks,
Romain
--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
diff mbox

Patch

diff --git a/Documentation/devicetree/bindings/power/poweroff.txt b/Documentation/devicetree/bindings/power/power-controller.txt
similarity index 100%
rename from Documentation/devicetree/bindings/power/poweroff.txt
rename to Documentation/devicetree/bindings/power/power-controller.txt
diff --git a/Documentation/devicetree/bindings/regulator/act8865-regulator.txt b/Documentation/devicetree/bindings/regulator/act8865-regulator.txt
index 01a5b07..dad6358 100644
--- a/Documentation/devicetree/bindings/regulator/act8865-regulator.txt
+++ b/Documentation/devicetree/bindings/regulator/act8865-regulator.txt
@@ -6,8 +6,8 @@  Required properties:
 - reg: I2C slave address
 
 Optional properties:
-- poweroff-source: Telling whether or not this pmic is controlling
-  the system power. See Documentation/devicetree/bindings/power/poweroff.txt .
+- system-power-controller: Telling whether or not this pmic is controlling
+  the system power. See Documentation/devicetree/bindings/power/power-controller.txt .
 
 Any standard regulator properties can be used to configure the single regulator.
 
diff --git a/drivers/regulator/act8865-regulator.c b/drivers/regulator/act8865-regulator.c
index 76301ed..9eec453 100644
--- a/drivers/regulator/act8865-regulator.c
+++ b/drivers/regulator/act8865-regulator.c
@@ -365,7 +365,7 @@  static int act8865_pmic_probe(struct i2c_client *client,
 		return ret;
 	}
 
-	if (of_system_has_poweroff_source(dev->of_node)) {
+	if (of_device_is_system_power_controller(dev->of_node)) {
 		if (!pm_power_off) {
 			act8865_i2c_client = client;
 			act8865->off_reg = off_reg;
diff --git a/include/linux/of.h b/include/linux/of.h
index b81dbcf..0abdd70 100644
--- a/include/linux/of.h
+++ b/include/linux/of.h
@@ -964,14 +964,14 @@  static inline int of_changeset_update_property(struct of_changeset *ocs,
 extern int of_resolve_phandles(struct device_node *tree);
 
 /**
  * of_system_has_poweroff_source - Tells if poweroff-source is found for device_node
  * @np: Pointer to the given device_node
  *
  * return true if present false otherwise
  */
-static inline bool of_system_has_poweroff_source(const struct device_node *np)
+static inline bool of_device_is_system_power_controller(const struct device_node *np)
 {
-	return of_property_read_bool(np, "poweroff-source");
+	return of_property_read_bool(np, "system-power-controller");
 }
 
 #endif /* _LINUX_OF_H */
@@ -964,14 +964,14 @@  static inline int of_changeset_update_property(struct of_changeset *ocs,
 
 /**
- * of_system_has_poweroff_source - Tells if poweroff-source is found for device_node
+ * of_device_is_system_power_controller - Tells if system-power-controller is found for device_node
  * @np: Pointer to the given device_node
  *